==> sensible_stackables-2.1.1%2B1.21.10-fabric-sources.jar: me/pajic/sensible_stackables/mixin/menu_fixes/AnvilMenuMixin.java <==
package me.pajic.sensible_stackables.mixin.menu_fixes;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.injector.wrapmethod.WrapMethod;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1706;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_3914;
import net.minecraft.class_3917;
import net.minecraft.class_4861;
import net.minecraft.class_8047;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.ModifyArg;

@Mixin(class_1706.class)
public abstract class AnvilMenuMixin extends class_4861 {

    @Shadow public abstract void method_24928();

    //? if 1.21.1 {
    /*public AnvilMenuMixin(@Nullable MenuType<?> type, int containerId, Inventory playerInventory, ContainerLevelAccess access) {
        super(type, containerId, playerInventory, access);
    }
    *///?} else {
    public AnvilMenuMixin(@Nullable class_3917<?> menuType, int containerId, class_1661 inventory, class_3914 access, class_8047 slotDefinition) {
        super(menuType, containerId, inventory, access, slotDefinition);
    }
    //?}

    @ModifyArg(
			//? if fabric || (neoforge && 1.21.1)
            method = "createResult",
			//? if neoforge && > 1.21.1
			//method = "createResultInternal",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/inventory/ResultContainer;setItem(ILnet/minecraft/world/item/ItemStack;)V",
                    ordinal = 4
            ),
            index = 1
    )
    private class_1799 modifyResult(class_1799 stack) {
        if (stack.method_31574(class_1802.field_8598) && stack.method_7947() > 1) stack.method_7939(1);
        return stack;
    }

    @ModifyExpressionValue(
			//? if fabric || (neoforge && 1.21.1)
			method = "createResult",
			//? if neoforge && > 1.21.1
			//method = "createResultInternal",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/item/ItemStack;getCount()I",
                    ordinal = 1
            )
    )
    private int modifyInputCountCondition(int original, @Local(ordinal = 0) class_1799 stack) {
        if (stack.method_31574(class_1802.field_8598)) return 1;
        return original;
    }

    @ModifyArg(
            method = "onTake",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/Container;setItem(ILnet/minecraft/world/item/ItemStack;)V",
                    ordinal = /*? if <= 1.21.1 {*//*0*//*?}*//*? if > 1.21.1 {*/3/*?}*/
            ),
            index = 1
    )
    private class_1799 modifyLeftInputOnTake(class_1799 original) {
        class_1799 stack = field_22480.method_5438(0);
        if (stack.method_31574(class_1802.field_8598) && stack.method_7947() > 1) {
            stack.method_7934(1);
            return stack;
        }
        return original;
    }

    @ModifyArg(
            method = "onTake",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/Container;setItem(ILnet/minecraft/world/item/ItemStack;)V",
                    ordinal = /*? if <= 1.21.1 {*//*3*//*?}*//*? if > 1.21.1 {*/2/*?}*/
            ),
            index = 1
    )
    private class_1799 modifyRightInputOnTake(class_1799 original) {
        class_1799 stack = field_22480.method_5438(1);
        if (stack.method_31574(class_1802.field_8598) && stack.method_7947() > 1) {
            stack.method_7934(1);
            return stack;
        }
        return original;
    }

    @WrapMethod(method = "onTake")
    private void triggerCreateResultOnTake(class_1657 player, class_1799 stack, Operation<Void> original) {
        original.call(player, stack);
        method_24928();
    }
}

==> sensible_stackables-2.1.3%2B1.21.1-fabric-sources.jar: me/pajic/sensible_stackables/mixin/menu_fixes/AnvilMenuMixin.java <==
package me.pajic.sensible_stackables.mixin.menu_fixes;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.injector.wrapmethod.WrapMethod;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1706;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_3914;
import net.minecraft.class_3917;
import net.minecraft.class_4861;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.ModifyArg;

@Mixin(class_1706.class)
public abstract class AnvilMenuMixin extends class_4861 {

    @Shadow public abstract void method_24928();

    //? if 1.21.1 {
    public AnvilMenuMixin(@Nullable class_3917<?> type, int containerId, class_1661 playerInventory, class_3914 access) {
        super(type, containerId, playerInventory, access);
    }
    //?} else {
    /*public AnvilMenuMixin(@Nullable MenuType<?> menuType, int containerId, Inventory inventory, ContainerLevelAccess access, ItemCombinerMenuSlotDefinition slotDefinition) {
        super(menuType, containerId, inventory, access, slotDefinition);
    }
    *///?}

    @ModifyArg(
			//? if fabric || (neoforge && 1.21.1)
            method = "createResult",
			//? if neoforge && > 1.21.1
			//method = "createResultInternal",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/inventory/ResultContainer;setItem(ILnet/minecraft/world/item/ItemStack;)V",
                    ordinal = 4
            ),
            index = 1
    )
    private class_1799 modifyResult(class_1799 stack) {
        if (stack.method_31574(class_1802.field_8598) && stack.method_7947() > 1) stack.method_7939(1);
        return stack;
    }

    @ModifyExpressionValue(
			//? if fabric || (neoforge && 1.21.1)
			method = "createResult",
			//? if neoforge && > 1.21.1
			//method = "createResultInternal",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/item/ItemStack;getCount()I",
                    ordinal = 1
            )
    )
    private int modifyInputCountCondition(int original, @Local(ordinal = 0) class_1799 stack) {
        if (stack.method_31574(class_1802.field_8598)) return 1;
        return original;
    }

    @ModifyArg(
            method = "onTake",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/Container;setItem(ILnet/minecraft/world/item/ItemStack;)V",
                    ordinal = /*? if <= 1.21.1 {*/0/*?}*//*? if > 1.21.1 {*//*3*//*?}*/
            ),
            index = 1
    )
    private class_1799 modifyLeftInputOnTake(class_1799 original) {
        class_1799 stack = field_22480.method_5438(0);
        if (stack.method_31574(class_1802.field_8598) && stack.method_7947() > 1) {
            stack.method_7934(1);
            return stack;
        }
        return original;
    }

    @ModifyArg(
            method = "onTake",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/Container;setItem(ILnet/minecraft/world/item/ItemStack;)V",
                    ordinal = /*? if <= 1.21.1 {*/3/*?}*//*? if > 1.21.1 {*//*2*//*?}*/
            ),
            index = 1
    )
    private class_1799 modifyRightInputOnTake(class_1799 original) {
        class_1799 stack = field_22480.method_5438(1);
        if (stack.method_31574(class_1802.field_8598) && stack.method_7947() > 1) {
            stack.method_7934(1);
            return stack;
        }
        return original;
    }

    @WrapMethod(method = "onTake")
    private void triggerCreateResultOnTake(class_1657 player, class_1799 stack, Operation<Void> original) {
        original.call(player, stack);
        method_24928();
    }
}
